summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorThierry Vignaud <tv@mageia.org>2013-05-01 20:40:56 +0000
committerThierry Vignaud <tv@mageia.org>2013-05-01 20:40:56 +0000
commit91be7ec5790068f43fd6b8ec52ce8e26c049fad2 (patch)
tree0d44a579489365449d16556f39da112765126fa5
parent4ad86465c65253dd077da6f7e7b60f31ea534f37 (diff)
downloaddrakx-backup-do-not-use-91be7ec5790068f43fd6b8ec52ce8e26c049fad2.tar
drakx-backup-do-not-use-91be7ec5790068f43fd6b8ec52ce8e26c049fad2.tar.gz
drakx-backup-do-not-use-91be7ec5790068f43fd6b8ec52ce8e26c049fad2.tar.bz2
drakx-backup-do-not-use-91be7ec5790068f43fd6b8ec52ce8e26c049fad2.tar.xz
drakx-backup-do-not-use-91be7ec5790068f43fd6b8ec52ce8e26c049fad2.zip
install 'basesystem-minimal' instead of 'basesystem' prior to add extra media
thus fixing "basesystem package not selected" (mga#9611)
-rw-r--r--perl-install/install/NEWS2
-rw-r--r--perl-install/install/any.pm6
2 files changed, 5 insertions, 3 deletions
diff --git a/perl-install/install/NEWS b/perl-install/install/NEWS
index 700d99e30..599d617c8 100644
--- a/perl-install/install/NEWS
+++ b/perl-install/install/NEWS
@@ -1,4 +1,6 @@
- include mount options in auto_inst.pl
+- install 'basesystem-minimal' instead of 'basesystem' prior to add extra media
+ thus fixing "basesystem package not selected" (mga#9611)
- make xdm installation automatic in auto_inst mode (mga#9875)
Version 15.47 - 30 April 2013
diff --git a/perl-install/install/any.pm b/perl-install/install/any.pm
index 5402f7aa8..8cdceafff 100644
--- a/perl-install/install/any.pm
+++ b/perl-install/install/any.pm
@@ -149,13 +149,13 @@ sub prep_net_suppl_media {
return if our $net_suppl_media_configured && network::tools::has_network_connection();
$net_suppl_media_configured = 1;
# needed so that one can install basesystem before adding suppl network media:
install::media::update_media($o->{packages});
require urpm::media;
urpm::media::configure($o->{packages});
- #- install basesystem now
- $o->do_pkgs->ensure_is_installed('basesystem', undef, 1);
+ #- install basesystem-minimal now
+ $o->do_pkgs->ensure_is_installed('basesystem-minimal', undef, 1);
# in case of no network install:
$o->{net} ||= {};
@@ -149,13 +149,13 @@ sub prep_net_suppl_media {
return if our $net_suppl_media_configured && network::tools::has_network_connection();
$net_suppl_media_configured = 1;
- # needed so that one can install basesystem before adding suppl network media:
+ # needed so that one can install basesystem-minimal before adding suppl network media:
install::media::update_media($o->{packages});
require urpm::media;